"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _scopedComponent = require("./scoped.component.js");

var _styleElementUtils = require("./style-element-utils.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe("<Scoped />", function () {
  beforeEach(function () {
    (0, _styleElementUtils.resetState)();
    Array.prototype.slice.call(document.querySelectorAll('style')).forEach(function (styleElement) {
      styleElement.remove();
    });
  });
  it("should generate and cleanup style tags", function () {
    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(0);
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(1);

    _reactDom.default.unmountComponentAtNode(el);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(0);
  });
  it("should dynamically create a style tag with local CSS", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      [kremling=\"0\"] .someRule, [kremling=\"0\"].someRule {\n        background-color: red;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should create local CSS for combined CSS statements & with regular", function () {
    var css = "\n      & .someRule, .wow {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      [kremling=\"0\"] .someRule, [kremling=\"0\"].someRule, .wow {\n        background-color: red;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should create local CSS for combined CSS statements regular with &", function () {
    var css = "\n      .wow, & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      .wow, [kremling=\"0\"] .someRule, [kremling=\"0\"].someRule {\n        background-color: red;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should create local CSS for combined CSS statements", function () {
    var css = "\n      & .wow, & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      [kremling=\"0\"] .wow, [kremling=\"0\"].wow, [kremling=\"0\"] .someRule, [kremling=\"0\"].someRule {\n        background-color: red;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should create local CSS for combined CSS statements and new lines", function () {
    var css = "\n      & .wow,\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      [kremling=\"0\"] .wow, [kremling=\"0\"].wow, [kremling=\"0\"] .someRule, [kremling=\"0\"].someRule {\n        background-color: red;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should create local CSS multiple css statements", function () {
    var css = "\n      & .wow,\n      & .someRule {\n        background-color: red;\n      }\n\n      & .oliver,\n      & .cromwell {\n        background-color: green;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      [kremling=\"0\"] .wow, [kremling=\"0\"].wow, [kremling=\"0\"] .someRule, [kremling=\"0\"].someRule {\n        background-color: red;\n      }\n\n      [kremling=\"0\"] .oliver, [kremling=\"0\"].oliver, [kremling=\"0\"] .cromwell, [kremling=\"0\"].cromwell {\n        background-color: green;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should dynamically create a style local CSS for non class/id selector", function () {
    var css = "\n      & div {\n        background-color: pink;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Ahoy hoy"))), el);

    expect(document.querySelectorAll('style[type="text/css"]')[0].innerHTML.trim()).toBe("\n      [kremling=\"0\"] div, div[kremling=\"0\"] {\n        background-color: pink;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should recycle style tags that have the same CSS", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el1 = document.createElement("div");
    var el2 = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el1);

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el2);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(1);

    _reactDom.default.unmountComponentAtNode(el1);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(1);

    _reactDom.default.unmountComponentAtNode(el2);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(0);
  });
  it("should dynamically create a style tag with global CSS", function () {
    var css = "\n      .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      .someRule {\n        background-color: red;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should create rules with a custom namespace", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css,
      namespace: "kackle"
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]")[0].innerHTML.trim()).toBe("\n      [kackle=\"0\"] .someRule, [kackle=\"0\"].someRule {\n        background-color: red;\n      }\n    ".trim());

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should pass through non element children", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css,
      namespace: "kackle"
    }, "5")), el);

    expect(el.innerHTML).toBe('<div>5</div>');

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("adds Kremling attribute to React Fragment children", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css,
      namespace: "kackle"
    }, _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", {
      id: "greeting"
    }, "Hello"), _react.default.createElement("div", {
      id: "farewell"
    }, "Bye")))), el);

    expect(el.querySelector("#greeting").getAttribute('kackle')).not.toBe(undefined);
    expect(el.querySelector("#farewell").getAttribute('kackle')).not.toBe(undefined);

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("adds Kremling attribute to nested React Fragment children", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css,
      namespace: "kackle"
    }, _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_react.default.Fragment, null, _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", {
      id: "greeting"
    }, "Hello"), _react.default.createElement("div", {
      id: "farewell"
    }, "Bye")))))), el);

    expect(el.querySelector("#greeting").getAttribute('kackle')).not.toBe(undefined);
    expect(el.querySelector("#farewell").getAttribute('kackle')).not.toBe(undefined);

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("adds Kremling attribute to mixture of React Fragment and DOM Element children", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css,
      namespace: "kackle"
    }, _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", {
      id: "greeting"
    }, "Hello"), _react.default.createElement("div", {
      id: "farewell"
    }, "Bye")), _react.default.createElement("div", {
      id: "color"
    }, "Blue"), _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", {
      id: "color2"
    }, "Green")))), el);

    expect(el.querySelector("#greeting").getAttribute('kackle')).not.toBe(undefined);
    expect(el.querySelector("#farewell").getAttribute('kackle')).not.toBe(undefined);
    expect(el.querySelector("#color").getAttribute('kackle')).not.toBe(undefined);
    expect(el.querySelector("#color2").getAttribute('kackle')).not.toBe(undefined);

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("returns null if child is null", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css,
      namespace: "kackle"
    }, "null")), el);

    expect(el.innerHTML).toBe('<div>null</div>');

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("returns null if child is undefined", function () {
    var css = "\n      & .someRule {\n        background-color: red;\n      }\n    ";
    var el = document.createElement("div");

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      css: css
    })), el);

    expect(el.innerHTML).toBe('<div></div>');

    _reactDom.default.unmountComponentAtNode(el);
  });
  it("should properly work with dynamically changing css props", function () {
    var Counter =
    /*#__PURE__*/
    function (_React$Component) {
      _inherits(Counter, _React$Component);

      function Counter() {
        var _getPrototypeOf2;

        var _this;

        _classCallCheck(this, Counter);

        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Counter)).call.apply(_getPrototypeOf2, [this].concat(args)));

        _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
          width: 100
        });

        return _this;
      }

      _createClass(Counter, [{
        key: "render",
        value: function render() {
          return _react.default.createElement(_scopedComponent.Scoped, {
            css: this.getCSS()
          }, _react.default.createElement("div", {
            id: this.props.id,
            onClick: this.update.bind(this)
          }, "Hello"));
        }
      }, {
        key: "getCSS",
        value: function getCSS() {
          return "\n            & .someRule {\n              width: ".concat(this.state.width, "%;\n            }\n        ");
        }
      }, {
        key: "update",
        value: function update() {
          this.setState({
            width: this.state.width + 10
          });
        }
      }]);

      return Counter;
    }(_react.default.Component);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(0);
    var el = document.createElement("div");
    document.body.appendChild(el);

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(Counter, {
      id: "a"
    }), _react.default.createElement(Counter, {
      id: "b"
    }), _react.default.createElement(Counter, {
      id: "c"
    })), el);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(1);
    el.querySelector('#a').click();
    el.querySelector('#a').click();
    el.querySelector('#b').click();
    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(3);

    _reactDom.default.unmountComponentAtNode(el);

    expect(document.querySelectorAll("style[type=\"text/css\"]").length).toBe(0);
  });
});
//# sourceMappingURL=scoped.component.test.js.map