"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _scopedComponent = require("./scoped.component.js");

var _styleElementUtils = require("./style-element-utils.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Scoped postcss />', function () {
  beforeEach(function () {
    (0, _styleElementUtils.resetState)();
    Array.prototype.slice.call(document.querySelectorAll('style')).forEach(function (styleElement) {
      styleElement.remove();
    });
  });
  it("should generate and cleanup style tags", function () {
    expect(document.head.querySelectorAll("style[type=\"text/css\"]").length).toBe(0);
    var css = {
      id: 1,
      styles: "[kremling=\"1\"] .someRule, [kremling=\"1\"].someRule {background-color: red;}"
    };
    var el = document.createElement('div');

    _reactDom.default.render(_react.default.createElement(_scopedComponent.Scoped, {
      postcss: css
    }, _react.default.createElement("div", {
      className: "crazy"
    }, "Okay")), el);

    expect(document.head.querySelectorAll("style[type=\"text/css\"]").length).toBe(1);

    _reactDom.default.unmountComponentAtNode(el);

    expect(document.head.querySelectorAll("style[type=\"text/css\"]").length).toBe(0);
  });
  it('should create a <style> tag with postcss styles', function () {
    var css = {
      id: 1,
      styles: "[kremling=\"1\"] .someRule, [kremling=\"1\"].someRule {background-color: red;}"
    };
    var el = document.createElement('div');

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      postcss: css
    }, _react.default.createElement("div", null, "Hello"))), el);

    expect(document.querySelectorAll('style').length).toBe(1);
    expect(document.querySelector('style').textContent).toBe(css.styles);
  });
  it('when webpack updates its styles, component should update the kremling attribute and inner css', function () {
    var css = {
      id: '1',
      styles: "[kremling-1] .someRule, [kremling-1].someRule {background-color: red;}"
    };

    var component = function component(style) {
      return _react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
        postcss: style
      }, _react.default.createElement("div", null, "Hello")));
    };

    var el = document.createElement('div');

    _reactDom.default.render(component(css), el);

    expect(document.querySelector('style').textContent).toBe(css.styles); // update css

    css = {
      id: '2',
      styles: "[kremling-2] .someRule, [kremling-2].someRule {background-color: green;}"
    };

    _reactDom.default.render(component(css), el);

    expect(document.querySelector('style').textContent).toBe(css.styles);
  });
  it('when the user updates its id, component should update <style> kremling attribute', function () {
    var css = {
      id: '1',
      styles: "[kremling-1] .someRule, [kremling-1].someRule {background-color: red;}"
    };

    var component = function component(style) {
      return _react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
        postcss: style
      }, _react.default.createElement("div", null, "Hello")));
    };

    var el = document.createElement('div');

    _reactDom.default.render(component(css), el);

    expect(document.querySelector('style').textContent).toBe(css.styles); // update css

    css = {
      id: 'custom-id',
      styles: "[kremling-1] .someRule, [kremling-1].someRule {background-color: red;}"
    };

    _reactDom.default.render(component(css), el);

    expect(document.querySelector('style').textContent).toBe(css.styles);
  });
  it("should increment/decrement <style> kremlings when there's multiples of the same component", function () {
    var css = {
      id: '1',
      styles: "[kremling=\"1\"] .someRule, [kremling=\"1\"].someRule {background-color: red;}"
    };
    var el1 = document.createElement('div');
    var el2 = document.createElement('div');
    expect(document.head.querySelectorAll('style').length).toBe(0);

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      postcss: css
    }, _react.default.createElement("div", null, "Hello"))), el1);

    expect(document.head.querySelectorAll('style').length).toBe(1);
    expect(document.head.querySelector('style').kremlings).toBe(1);

    _reactDom.default.render(_react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
      postcss: css
    }, _react.default.createElement("div", null, "Hello"))), el2);

    expect(document.head.querySelectorAll('style').length).toBe(1);
    expect(document.head.querySelector('style').kremlings).toBe(2);

    _reactDom.default.unmountComponentAtNode(el1);

    expect(document.head.querySelector('style').kremlings).toBe(1);

    _reactDom.default.unmountComponentAtNode(el2);

    expect(document.head.querySelector('style')).toBe(null);
  });
  it("shouldn't throw errors when empty postcss.styles is passed in", function () {
    var css = {
      id: '1',
      styles: ''
    };

    var component = function component(style) {
      return _react.default.createElement("div", null, _react.default.createElement(_scopedComponent.Scoped, {
        postcss: style
      }, _react.default.createElement("div", null, "Hello")));
    };

    var el = document.createElement('div');

    _reactDom.default.render(component(css), el);

    expect(document.head.querySelector('style').innerHTML).toEqual('');
  });
});
//# sourceMappingURL=scoped.postcss.test.js.map