"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCss = useCss;

var _react = require("react");

var _scopedComponent = require("./scoped.component.js");

var _styleElementUtils = require("./style-element-utils.js");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function useCss(css, overrideNamespace) {
  var isPostCss = Boolean(css && css.id && css.styles);
  var namespace = overrideNamespace || isPostCss && css.namespace || _scopedComponent.Scoped.defaultNamespace;

  var _useState = (0, _react.useState)(function () {
    return getStyleElement(null, isPostCss, css, namespace);
  }),
      _useState2 = _slicedToArray(_useState, 2),
      styleElement = _useState2[0],
      setStyleElement = _useState2[1];

  useStyleElement();
  return _defineProperty({}, styleElement.kremlingAttr, String(styleElement.kremlingValue).toString());

  function useStyleElement() {
    (0, _react.useLayoutEffect)(function () {
      var newStyleElement = getStyleElement(styleElement, isPostCss, css, namespace);
      setStyleElement(newStyleElement);
      return function () {
        if (--styleElement.kremlings === 0) {
          document.head.removeChild(styleElement);
          delete _styleElementUtils.styleTags[css];
        }
      };
    }, [css, namespace, styleElement, setStyleElement, isPostCss]);
  }
}

function getStyleElement(oldStyleElement, isPostCss, css, namespace) {
  var kremlingAttr = isPostCss ? namespace : "data-".concat(namespace);
  var kremlingValue = isPostCss ? css.id : (0, _styleElementUtils.incrementCounter)();
  var styleElement = isPostCss ? _styleElementUtils.styleTags[css.styles] : _styleElementUtils.styleTags[css];

  if (styleElement) {
    // This css is already being used by another instance of the component, or another component altogether.
    if (styleElement !== oldStyleElement) {
      styleElement.kremlings++;
    }
  } else {
    var kremlingSelector = "[".concat(kremlingAttr, "='").concat(kremlingValue, "']");
    var rawCss = isPostCss ? css.styles : css;
    var cssToInsert = isPostCss ? css.styles : (0, _styleElementUtils.transformCss)(css, kremlingSelector);
    styleElement = document.createElement('style');
    styleElement.type = 'text/css';
    styleElement.textContent = cssToInsert;
    styleElement.kremlings = 1;
    styleElement.kremlingAttr = kremlingAttr;
    styleElement.kremlingValue = kremlingValue;
    document.head.appendChild(styleElement);
    _styleElementUtils.styleTags[rawCss] = styleElement;
  }

  return styleElement;
}
//# sourceMappingURL=use-css.hook.js.map